export function formatTimestampToDateString(timestamp) {
  let date = new Date(timestamp);
  let year = date.getFullYear();
  let month = date.getMonth() + 1;
  let day = date.getDate();
  function addLeadingZero(number) {
    return number < 10 ? '0' + number : number;
  }

  return year + '-' + addLeadingZero(month) + '-' + addLeadingZero(day);
}

export function  decimalValidator(rule, value, callback) {
  if (value === '') {
    callback();
  } else {
    // 使用正则表达式匹配最多三位数，其中一位为小数的格式
    const reg = /^\d{1,2}(\.\d?)?$/;
    if (!reg.test(value)) {
      callback(new Error('请输入正确的计划工时(范围从0到99.9的数字)'));
    }else if (parseFloat(value) <= 0) {
      callback(new Error('计划工时必须大于0'));
    }
    else {
      callback();
    }
  }
}

export function validateDateRange0(startDate, endDate) {
  return function(rule, value, callback) {
    const actualStartDate = startDate;
    const actualEndDate = endDate;

    if (!actualStartDate && !actualEndDate) {
      callback();
    } else if (new Date(actualStartDate) > new Date(actualEndDate)) {
      callback(new Error('实际开始时间不能晚于实际结束时间'));
    } else {
      callback();
    }
  };
}
export function validateDateRange1(startDate, endDate) {
  return function(rule, value, callback) {
    const plannedStartDate = startDate;
    const plannedEndDate = endDate;

    if (!plannedStartDate && !plannedEndDate) {
      callback();
    } else if (new Date(plannedStartDate) > new Date(plannedEndDate)) {
      callback(new Error('计划开始时间不能晚于计划结束时间'));
    } else {
      callback();
    }
  };
}



