package com.sooka.sponest.event.centereventtdeptevent.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.centereventtdeptevent.domain.CentereventDeptEvent;
import com.sooka.sponest.event.centereventtdeptevent.service.ICentereventDeptEventService;
import com.sooka.sponest.event.utils.EventProducerUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.TreeSet;
import java.util.stream.Collectors;

/**
 * 事件部门Controller
 *
 * @author 朱哲
 * @date 2022-08-29
 */
@Api(tags = "事件部门")
@RestController
@RequestMapping("/centereventtdeptevent")
public class CentereventDeptEventController extends BaseController {

    @Autowired
    private ICentereventDeptEventService centereventTDeptEventService;

    /**
     * 查询事件部门列表
     */
    @RequiresPermissions("centereventtdeptevent:centereventtdeptevent:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventDeptEvent centereventTDeptEvent) {
        startPage();
        List<CentereventDeptEvent> list = centereventTDeptEventService.selectCentereventTDeptEventList(centereventTDeptEvent);
        return getDataTable(list);
    }

    /**
     * 查询事件部门列表
     */
    @ApiOperation("查询事件部门列表")
    @GetMapping("/getAllCentereventDeptEvent")
    public R getAllCentereventDeptEvent(CentereventDeptEvent centereventTDeptEvent) {
        List<CentereventDeptEvent> list = centereventTDeptEventService.selectCentereventTDeptEventList(centereventTDeptEvent);
        return R.ok(list.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(CentereventDeptEvent::getDeptId))), ArrayList::new)));
    }

    /**
     * 导出事件部门列表
     */
    @RequiresPermissions("centereventtdeptevent:centereventtdeptevent:export")
    @Log(title = "事件部门", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventDeptEvent centereventTDeptEvent) {
        List<CentereventDeptEvent> list = centereventTDeptEventService.selectCentereventTDeptEventList(centereventTDeptEvent);
        ExcelUtil<CentereventDeptEvent> util = new ExcelUtil<>(CentereventDeptEvent.class);
        util.exportExcel(response, list, "事件部门数据");
    }

    /**
     * 获取事件部门详细信息
     */
    @RequiresPermissions("centereventtdeptevent:centereventtdeptevent:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(centereventTDeptEventService.selectCentereventTDeptEventById(id));
    }

    /**
     * 新增事件部门
     */
//    @RequiresPermissions("centereventtdeptevent:centereventtdeptevent:add")
    @ApiOperation("新增事件部门")
    @Log(title = "事件部门", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody CentereventDeptEvent centereventTDeptEvent) {
        int result = centereventTDeptEventService.insertCentereventTDeptEvent(centereventTDeptEvent);
        EventProducerUtil.publish(centereventTDeptEvent.getEventCode(), BusinessType.UPDATE);
        return toAjax(result);
    }

    /**
     * 修改事件部门
     */
    @RequiresPermissions("centereventtdeptevent:centereventtdeptevent:edit")
    @Log(title = "事件部门", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventDeptEvent centereventTDeptEvent) {
        return toAjax(centereventTDeptEventService.updateCentereventTDeptEvent(centereventTDeptEvent));
    }

    /**
     * 删除事件部门
     */
    @RequiresPermissions("centereventtdeptevent:centereventtdeptevent:remove")
    @Log(title = "事件部门", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTDeptEventService.deleteCentereventTDeptEventByIds(ids));
    }


    /**
     * 根据事件编码查询事件部门信息
     */
    @ApiOperation("根据事件编码查询事件部门信息")
    @GetMapping("/selectByEventCode")
    public R selectByEventCode(String eventCode) {
        if (StringUtils.isBlank(eventCode)) {
            return R.fail();
        }
        return R.ok(centereventTDeptEventService.selectByEventCode(eventCode));
    }
}
