package com.sooka.sponest.event.centereventtdeptevent.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.datascope.base.service.BaseService;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.domain.SysDept;
import com.sooka.sponest.event.centereventtdeptevent.domain.CentereventDeptEvent;
import com.sooka.sponest.event.centereventtdeptevent.mapper.CentereventDeptEventMapper;
import com.sooka.sponest.event.centereventtdeptevent.service.ICentereventDeptEventService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * 事件部门Service业务层处理
 *
 * @author 朱哲
 * @date 2022-08-29
 */
@Service
public class CentereventDeptEventServiceImpl extends BaseService implements ICentereventDeptEventService {

    @Autowired
    private CentereventDeptEventMapper centereventTDeptEventMapper;

    /**
     * 查询事件部门列表
     *
     * @param centereventTDeptEvent 事件部门
     * @return 事件部门
     */
    @Override
    public List<CentereventDeptEvent> selectCentereventTDeptEventList(CentereventDeptEvent centereventTDeptEvent) {
        return centereventTDeptEventMapper.selectCentereventTDeptEventList(centereventTDeptEvent);
    }

    /**
     * 查询事件部门
     *
     * @param id 事件部门主键
     * @return 事件部门
     */
    @Override
    public CentereventDeptEvent selectCentereventTDeptEventById(String id) {
        return centereventTDeptEventMapper.selectCentereventTDeptEventById(id);
    }

    /**
     * 新增事件部门
     *
     * @param centereventTDeptEvent 事件部门
     * @return 结果
     */
    @Transactional
    @Override
    public int insertCentereventTDeptEvent(CentereventDeptEvent centereventTDeptEvent) {
        if (null == centereventTDeptEvent.getCreateName()) {// AI上报已赋值
            centereventTDeptEvent.setCreateBy(SecurityUtils.getUserId().toString());
            centereventTDeptEvent.setCreateName(SecurityUtils.getLoginUser().getSysUser().getNickName());
            centereventTDeptEvent.setCreateTime(DateUtils.getNowDate());
        }
        return centereventTDeptEventMapper.insertCentereventTDeptEvent(centereventTDeptEvent);
    }

    /**
     * 修改事件部门
     *
     * @param centereventTDeptEvent 事件部门
     * @return 结果
     */
    @Transactional
    @Override
    public int updateCentereventTDeptEvent(CentereventDeptEvent centereventTDeptEvent) {
        return centereventTDeptEventMapper.updateCentereventTDeptEvent(centereventTDeptEvent);
    }

    /**
     * 批量删除事件部门
     *
     * @param ids 需要删除的事件部门主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteCentereventTDeptEventByIds(String[] ids) {
        return centereventTDeptEventMapper.deleteCentereventTDeptEventByIds(ids);
    }


    @Override
    public List<CentereventDeptEvent> selectByEventCode(String eventCode) {
        List<CentereventDeptEvent> centereventDeptEvents = centereventTDeptEventMapper.selectByEventCode(eventCode);
        List<SysDept> sysDeptList = SecurityUtils.getLoginUser().getSysUser().getDepts();
        List<CentereventDeptEvent> resultList = new ArrayList();
        for (SysDept sysDept : sysDeptList) {
            for (CentereventDeptEvent centereventDeptEvent : centereventDeptEvents) {
                if (sysDept.getDeptId().equals(centereventDeptEvent.getDeptId())) {
                    resultList.add(centereventDeptEvent);
                }
            }
        }
        if (resultList.isEmpty()) {
            return centereventDeptEvents;
        }
        return resultList;
    }

    @Transactional
    @Override
    public int updateCentereventTDeptEventOtherDeptIdWyc(String eventCode, String deptId) {
        return centereventTDeptEventMapper.updateCentereventTDeptEventOtherDeptIdWyc(eventCode, deptId);
    }

    @Override
    public int selectCentereventTDeptEventByEventCode(String eventCode, String deptId) {
        return centereventTDeptEventMapper.selectCentereventTDeptEventByEventCode(eventCode, deptId);
    }

    @Transactional
    @Override
    public int updateCentereventTDeptEventCf(String eventCode) {
        return centereventTDeptEventMapper.updateCentereventTDeptEventCf(eventCode);
    }

    @Transactional
    @Override
    public int updateCentereventTDeptEventByCodeDeptId(CentereventDeptEvent centereventTDeptEvent) {
        return centereventTDeptEventMapper.updateCentereventTDeptEventByCodeDeptId(centereventTDeptEvent);
    }
}
