package com.sooka.sponest.event.centereventtdutysystem.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.sooka.sponest.event.centereventtdutysystem.domain.CentereventTDutySystem;
import com.sooka.sponest.event.centereventtdutysystem.domain.CentereventTDutySystemVo;
import com.sooka.sponest.event.centereventtdutysystem.service.ICentereventTDutySystemService;
import com.sooka.sponest.event.centereventteventcatalogue.domain.CentereventTEventcatalogue;
import com.sooka.sponest.event.centereventteventcatalogue.service.ICentereventTEventcatalogueService;
import com.sooka.sponest.event.utils.RemoteApiUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * 责任制Controller
 *
 * @author lyq
 * @date 2022-11-26
 */
@Api(tags = "责任制")
@RestController
@RequestMapping("/dutysystem")
public class CentereventTDutySystemController extends BaseController {

    @Autowired
    private ICentereventTDutySystemService centereventTDutySystemService;

    @Autowired
    private ICentereventTEventcatalogueService centereventTEventcatalogueService;

    /**
     * 查询责任制列表
     */
    @RequiresPermissions("eventtype:eventtype:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTDutySystem centereventTDutySystem) {
        startPage();
        List<CentereventTDutySystem> list = centereventTDutySystemService.selectCentereventTDutySystemList(centereventTDutySystem);
        return getDataTable(list);
    }

    /**
     * 查询责任制列表
     */
    @ApiOperation("查询责任制列表")
    @GetMapping("/getAllCentereventTDutySystem")
    public R getAllCentereventTDutySystem(CentereventTDutySystem centereventTDutySystem) {
        return R.ok(centereventTDutySystemService.selectCentereventTDutySystemList(centereventTDutySystem));
    }

    /**
     * 导出责任制列表
     */
    @RequiresPermissions("eventtype:eventtype:export")
    @Log(title = "责任制", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTDutySystem centereventTDutySystem) {
        List<CentereventTDutySystem> list = centereventTDutySystemService.selectCentereventTDutySystemList(centereventTDutySystem);
        ExcelUtil<CentereventTDutySystem> util = new ExcelUtil<>(CentereventTDutySystem.class);
        util.exportExcel(response, list, "责任制数据");
    }

    /**
     * 获取责任制详细信息
     */
    @RequiresPermissions("eventtype:eventtype:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(centereventTDutySystemService.selectCentereventTDutySystemById(id));
    }

    /**
     * 新增责任制
     */
    @RequiresPermissions("eventtype:eventtype:add")
    @Log(title = "责任制", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody CentereventTDutySystem centereventTDutySystem) {
        return toAjax(centereventTDutySystemService.insertCentereventTDutySystem(centereventTDutySystem));
    }

    @ApiOperation("新增、修改责任制")
    @Log(title = "责任制", businessType = BusinessType.OTHER)
    @PostMapping("/addOrUpdate")
    public AjaxResult addOrUpdate(@Validated @RequestBody CentereventTDutySystem centereventTDutySystem) {
        int result = 0;
        try {
            if (StringUtils.isBlank(centereventTDutySystem.getId())) {
                result = centereventTDutySystemService.insertCentereventTDutySystem(centereventTDutySystem);
            } else {
                result = centereventTDutySystemService.updateCentereventTDutySystem(centereventTDutySystem);
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return toAjax(result);
    }

    @ApiOperation("批量新增、修改责任制")
    @Log(title = "责任制", businessType = BusinessType.OTHER)
    @PostMapping("/addOrUpdateAll")
    public AjaxResult addOrUpdateAll(@RequestBody CentereventTDutySystemVo centereventTDutySystemVo) {
        if (StringUtils.isEmpty(centereventTDutySystemVo.getCentereventTDutySystemList())) {
            return AjaxResult.error("请输入姓名/手机号码!");
        }
        // 提取当前发送过短信的电话号
        CentereventTDutySystem centereventTDutySystem = new CentereventTDutySystem();
        centereventTDutySystem.setDepteventId(centereventTDutySystemVo.getCentereventTDutySystemList().get(0).getDepteventId());
        List<String> oldPhones = centereventTDutySystemService.selectCentereventTDutySystemList(centereventTDutySystem).stream().map(CentereventTDutySystem::getTelphone).collect(Collectors.toList());
        try {
            centereventTDutySystemVo.getCentereventTDutySystemList().forEach(item -> {
                if (StringUtils.isBlank(item.getId())) {
                    centereventTDutySystemService.insertCentereventTDutySystem(item);
                } else {
                    centereventTDutySystemService.updateCentereventTDutySystem(item);
                }
            });
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        // 消息发送，极光推送
        if (StringUtils.isNotEmpty(centereventTDutySystemVo.getCentereventTDutySystemList())) {
            String userName = SecurityUtils.getLoginUser().getSysUser().getNickName();
            String phone = SecurityUtils.getLoginUser().getSysUser().getPhonenumber();
            CentereventTEventcatalogue centereventTEventcatalogue = new CentereventTEventcatalogue();
            centereventTEventcatalogue.setEventCode(centereventTDutySystemVo.getEventCode());
            centereventTEventcatalogue = centereventTEventcatalogueService.selectCentereventTEventcatalogueByEventCode(centereventTEventcatalogue);
            String message = centereventTEventcatalogue.getAddress() + "发生" + centereventTEventcatalogue.getEventTypeXl() + "事件，请联系：" + userName + "，联系电话：" + phone;
            // 提取新传入的责任制对象
            List<CentereventTDutySystem> dutySystems = centereventTDutySystemVo.getCentereventTDutySystemList().stream().filter(item -> !oldPhones.contains(item.getTelphone())).collect(Collectors.toList());
            // 提取电话号
            Set<String> phones = dutySystems.stream().map(CentereventTDutySystem::getTelphone).collect(Collectors.toSet());
            // 提取userId
            Set<Long> userIds = dutySystems.stream().filter(Objects::nonNull).map(CentereventTDutySystem::getUserId).collect(Collectors.toSet());
            // 推送
            RemoteApiUtil.getInstance().sendMessageAndJg(phones, userIds, message, centereventTDutySystemVo.getEventCode(), centereventTDutySystemVo.getEventName());
        }
        return toAjax(centereventTDutySystemVo.getCentereventTDutySystemList().size());
    }

    /**
     * 修改责任制
     */
    @RequiresPermissions("eventtype:eventtype:edit")
    @Log(title = "责任制", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTDutySystem centereventTDutySystem) {
        return toAjax(centereventTDutySystemService.updateCentereventTDutySystem(centereventTDutySystem));
    }

    /**
     * 删除责任制
     */
//    @RequiresPermissions("eventtype:eventtype:remove")
    @ApiOperation("删除责任制")
    @Log(title = "责任制", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        int result = 0;
        try {
            result = centereventTDutySystemService.deleteCentereventTDutySystemByIds(ids);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return toAjax(result);
    }
}
