package com.sooka.sponest.event.centereventtdutysystem.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.sooka.sponest.event.centereventtdutysystem.domain.CentereventTDutySystem;
import com.sooka.sponest.event.centereventtdutysystem.mapper.CentereventTDutySystemMapper;
import com.sooka.sponest.event.centereventtdutysystem.service.ICentereventTDutySystemService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 责任制Service业务层处理
 *
 * @author lyq
 * @date 2022-11-26
 */
@Service
public class CentereventTDutySystemServiceImpl implements ICentereventTDutySystemService {

    @Autowired
    private CentereventTDutySystemMapper centereventTDutySystemMapper;

    /**
     * 查询责任制列表
     *
     * @param centereventTDutySystem 责任制
     * @return 责任制
     */
    @Override
    public List<CentereventTDutySystem> selectCentereventTDutySystemList(CentereventTDutySystem centereventTDutySystem) {
        return centereventTDutySystemMapper.selectCentereventTDutySystemList(centereventTDutySystem);
    }

    /**
     * 查询责任制
     *
     * @param id 责任制主键
     * @return 责任制
     */
    @Override
    public CentereventTDutySystem selectCentereventTDutySystemById(String id) {
        return centereventTDutySystemMapper.selectCentereventTDutySystemById(id);
    }

    /**
     * 新增责任制
     *
     * @param centereventTDutySystem 责任制
     * @return 结果
     */
    @Transactional
    @Override
    public int insertCentereventTDutySystem(CentereventTDutySystem centereventTDutySystem) {
        centereventTDutySystem.setId(IdUtils.simpleUUID());
        centereventTDutySystem.setCreateBy(SecurityUtils.getUserId().toString());
        centereventTDutySystem.setCreateTime(DateUtils.getNowDate());
        return centereventTDutySystemMapper.insertCentereventTDutySystem(centereventTDutySystem);
    }

    /**
     * 修改责任制
     *
     * @param centereventTDutySystem 责任制
     * @return 结果
     */
    @Transactional
    @Override
    public int updateCentereventTDutySystem(CentereventTDutySystem centereventTDutySystem) {
        centereventTDutySystem.setUpdateBy(SecurityUtils.getUserId().toString());
        centereventTDutySystem.setUpdateTime(DateUtils.getNowDate());
        return centereventTDutySystemMapper.updateCentereventTDutySystem(centereventTDutySystem);
    }

    /**
     * 批量删除责任制
     *
     * @param ids 需要删除的责任制主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteCentereventTDutySystemByIds(String[] ids) {
        return centereventTDutySystemMapper.deleteCentereventTDutySystemByIds(ids);
    }
}
