package com.sooka.sponest.event.centereventteventcatalogue.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.DataConvertUtil;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.utils.DeptLevelUtil;
import com.sooka.sponest.event.centereventteventcatalogue.domain.vo.VisuForestCloudMapVO;
import com.sooka.sponest.event.centereventteventcatalogue.service.ICenterEventReportService;
import com.sooka.sponest.event.centereventteventtype.domain.CentereventTEventtype;
import com.sooka.sponest.event.centereventteventtype.service.ICentereventTEventtypeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import static com.ruoyi.common.core.utils.DataConvertUtil.*;
import static com.ruoyi.common.core.utils.DateUtils.YYYY_MM_DD;

/**
 * @program: sooka
 * @description: 事件中心-大数据控制器
 * @author: lyq
 * @create: 2022-10-26
 **/
@Api(tags = "大数据")
@RestController
@RequestMapping("/eventreport")
public class CenterEventReportController extends BaseController {

    @Autowired
    private ICenterEventReportService centerEventReportService;

    @Autowired
    private ICentereventTEventtypeService centereventTEventtypeService;

    @ApiOperation("查询事件总数")
    @PostMapping("/getTotal")
    public R getTotal(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventTotal(visuForestCloudMapVO));
    }

    @ApiOperation("查询事件总数")
    @PostMapping("/getTotalMore")
    public R getTotalMore(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("total", centerEventReportService.getEventTotal(visuForestCloudMapVO));
        visuForestCloudMapVO.setDiff(0L);// 当日
        resultMap.put("day", centerEventReportService.getEventTotal(visuForestCloudMapVO));
        LocalDate currentDate = LocalDate.now();
        int dayOfMonth = currentDate.getDayOfMonth() - 1;
        visuForestCloudMapVO.setDiff(Long.valueOf(dayOfMonth));// 当月
        resultMap.put("month", centerEventReportService.getEventTotal(visuForestCloudMapVO));
        return R.ok(resultMap);
    }

    @ApiOperation("事件来源、类型统计")
    @PostMapping("/getEventSourceAndTypeStatistics")
    public R getEventSourceAndTypeStatistics(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        Map<String, List<Map<String, Object>>> resultMap = new HashMap<>();
        resultMap.put("source", centerEventReportService.getEventCountGroupByReportSource(visuForestCloudMapVO));
        resultMap.put("type", centerEventReportService.getEventCountGroupByEventTypeXl(visuForestCloudMapVO));
        return R.ok(resultMap);
    }

    @ApiOperation("事件类型统计")
    @PostMapping("/getEventTypeStatistics")
    public R getEventTypeStatistics(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventCountGroupByEventTypeXl(visuForestCloudMapVO));
    }

    @ApiOperation("事件类型雷达图")
    @PostMapping("/getEventTypeRadar")
    public R getEventTypeRadar(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        List<Map<String, Object>> result = centerEventReportService.getEventTypeRadar(visuForestCloudMapVO);
        return R.ok(convertToMap(result, Arrays.asList("name", "value")));
    }

    @ApiOperation("起火原因统计")
    @PostMapping("/getEventCountGroupByFireSource")
    public R getEventCountGroupByFireSource(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventCountGroupByFireSource(visuForestCloudMapVO));
    }

    @ApiOperation("火灾等级统计")
    @PostMapping("/getEventCountGroupByFireRisk")
    public R getEventCountGroupByFireRisk(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventCountGroupByFireRisk(visuForestCloudMapVO));
    }

    @ApiOperation("火险等级统计")
    @PostMapping("/getEventCountGroupByFireInsurance")
    public R getEventCountGroupByFireInsurance(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventCountGroupByFireInsurance(visuForestCloudMapVO));
    }

    @ApiOperation("火灾种类统计")
    @PostMapping("/getEventCountGroupByFireType")
    public R getEventCountGroupByFireType(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventCountGroupByFireType(visuForestCloudMapVO));
    }

    @ApiOperation("历次火灾概况")
    @PostMapping("/getEventInfoList")
    public R getEventInfoList(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventInfoList(visuForestCloudMapVO));
    }

    @ApiOperation("设备上报事件数量")
    @PostMapping("/getAIEventNum")
    public R getAIEventNum(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getAIEventCountGroupByReportor(visuForestCloudMapVO));
    }

    @ApiOperation("事件趋势")
    @PostMapping("/getEventTrend")
    public R getEventTrend(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        String format = "%Y-%m";
        LocalDate localDate = LocalDate.now();
        if (visuForestCloudMapVO.getYearMonth().contains(String.valueOf(localDate.getYear()))) {
            format = "%Y";
        } else if (visuForestCloudMapVO.getYearMonth().contains(localDate.format(DateTimeFormatter.ofPattern(YYYY_MM_DD)))) {
            format = "%Y-%m-%d";
        }
        visuForestCloudMapVO.setDay(format);
        List<Map<String, Object>> result = centerEventReportService.getEventCountGroupByYearMonth(visuForestCloudMapVO);
        return R.ok(completionDate(result, visuForestCloudMapVO.getYearMonth(), "day", "daycount"));
    }

    @ApiOperation("事件类型年度统计")
    @PostMapping("/getEventTypeYearStatistics")
    public R getEventTypeYearStatistics(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        if (StringUtils.isEmpty(visuForestCloudMapVO.getYearMonth())) {
            visuForestCloudMapVO.setYearMonth(DateUtils.getLast30Days());
        }
        String format = "%Y-%m";
        LocalDate localDate = LocalDate.now();
        if (visuForestCloudMapVO.getYearMonth().contains(String.valueOf(localDate.getYear()))) {
            format = "%Y";
        } else if (visuForestCloudMapVO.getYearMonth().contains(localDate.format(DateTimeFormatter.ofPattern(YYYY_MM_DD)))) {
            format = "%Y-%m-%d";
        }
        visuForestCloudMapVO.setDay(format);
        List<Map<String, Object>> result = centerEventReportService.getEventTypeCountGroupByYearMonth(visuForestCloudMapVO);
        // 补全日期
        result = completionDate(result, visuForestCloudMapVO.getYearMonth(), "day", Arrays.asList(visuForestCloudMapVO.getEventTypeId()));
        // key->label
        Map<String, String> eventTypeMap = centereventTEventtypeService.selectCentereventTEventtypeList(new CentereventTEventtype()).stream().collect(
                Collectors.toMap(CentereventTEventtype::getId, CentereventTEventtype::getEventTypeName));
        return R.ok(DataConvertUtil.convertKeyToLabel(result, eventTypeMap));
    }

    @ApiOperation("事件部门统计")
    @PostMapping("/getEventDeptStatistics")
    public R getEventDeptStatistics(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        // 默认数据权限，传deptId查询本部门及以下
        List<Map<String, Object>> resultList = centerEventReportService.getEventCountGroupByEventDept(visuForestCloudMapVO);
        // DeptLevelUtil.getDeptLevel中deptIdu要求非空
        if (StringUtils.isBlank(visuForestCloudMapVO.getDeptId())) {
            visuForestCloudMapVO.setDeptId(String.valueOf(SecurityUtils.getLoginUser().getSysUser().getDeptId()));
        }
        return R.ok(SpringUtils.getBean(DeptLevelUtil.class).getDeptLevel(visuForestCloudMapVO.getDeptId(), resultList, "value"));
    }

    @ApiOperation("事件部门年度统计")
    @PostMapping("/getEventDeptYearStatistics")
    public R getEventDeptYearStatistics(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        List<Map<String, Object>> result = centerEventReportService.getEventDeptCountGroupByYearMonth(visuForestCloudMapVO);
        return R.ok(convert2DArray(result, Arrays.asList("day", "num", "name")));
    }

    @ApiOperation("事件分布热力图")
    @PostMapping("/getHeatMap")
    public R getHeatMap(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        List<Map<String, Object>> result = centerEventReportService.getEventLatLng(visuForestCloudMapVO);
        return R.ok(convert2DArray(result, Arrays.asList("latitude", "longitude", "num")));
    }

    @ApiOperation("事件状态统计")
    @PostMapping("/getEventStatusStatistics")
    public R getEventStatusStatistics(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventCountGroupByEventStatus(visuForestCloudMapVO));
    }

    @ApiOperation("事件来源统计")
    @PostMapping("/getEventSourceStatistics")
    public R getEventSourceStatistics(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.getEventCountGroupByReportSource(visuForestCloudMapVO));
    }

    @ApiOperation("事件告警情况统计")
    @PostMapping("/getEventGjnums")
    public R getEventGjnumsMap(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        // 查询当月的事件数量  累计告警数
        Map<String, Object> params = new HashMap<>();
        params.put("eventCode", "eventCode");
        params.put("noteventStatus", Arrays.asList("forest_event_status_3", "forest_event_status_4"));
        visuForestCloudMapVO.setParamsHashmap(params);
        int num2 = centerEventReportService.getEventGjnumsMap(visuForestCloudMapVO);
        // 查询当日的事件数量  今日告警数
        params.put("day", "day");
        visuForestCloudMapVO.setParamsHashmap(params);
        int num1 = centerEventReportService.getEventGjnumsMap(visuForestCloudMapVO);
        // 查询当月的事件涉及的部门的个数  涉及部门
        params.clear();
        params.put("eventdept", "eventdept");
        visuForestCloudMapVO.setParamsHashmap(params);
        int num3 = centerEventReportService.getEventGjnumsMap(visuForestCloudMapVO);
        // 查询当月的告事件涉及的事件小类的类型数量  告警种类数
        params.clear();
        params.put("eventTypeXl", "eventTypeXl");
        visuForestCloudMapVO.setParamsHashmap(params);
        int num4 = centerEventReportService.getEventGjnumsMap(visuForestCloudMapVO);
        // 返回参数
        Map<String, Integer> resultMap = new HashMap<>();
        resultMap.put("num1", num1);
        resultMap.put("num2", num2);
        resultMap.put("num3", num3);
        resultMap.put("num4", num4);
        return R.ok(resultMap);
    }

    @ApiOperation("事件列表")
    @PostMapping("/selectEventList")
    public R selectEventList(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventReportService.selectEventList(visuForestCloudMapVO));
    }
}
