package com.sooka.sponest.event.centereventteventcatalogue.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.RemoteDeptService;
import com.sooka.sponest.event.centereventteventcatalogue.domain.bo.VisuForestCloudTodayEventsBO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.bo.VisuForestEventTodayEventListBO;
import com.sooka.sponest.event.centereventteventcatalogue.domain.vo.VisuForestCloudMapVO;
import com.sooka.sponest.event.centereventteventcatalogue.service.ICenterEventViewService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.ArrayUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

import static com.ruoyi.common.core.utils.DataConvertUtil.completionDate;

/**
 * @program: sooka
 * @description: 事件中心-可视化控制器
 * @author: lyq
 * @create: 2022-10-26
 **/
@Api(tags = "可视化")
@RestController
@RequestMapping("/eventview")
public class CenterEventViewController extends BaseController {

    @Autowired
    private ICenterEventViewService centerEventViewService;

    @ApiOperation("事件状态、来源统计")
    @PostMapping("/selectTodayEvents")
    public R<VisuForestCloudTodayEventsBO> selectTodayEvents(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        return R.ok(centerEventViewService.selectTodayEvents(visuForestCloudMapVO));
    }

    @ApiOperation("查询部门事件数量")
    @PostMapping("/selectDeptEventCount")
    public R selectDeptEventCount(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        return R.ok(centerEventViewService.selectDeptEventCount(visuForestCloudMapVO));
    }

    @ApiOperation("查询事件列表")
    @PostMapping("/selectEventList")
    public R selectEventList(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        long size = visuForestCloudMapVO.getPageSize();
        long start = (visuForestCloudMapVO.getPageNum() - 1) * size;
        visuForestCloudMapVO.setPageNum(start);
        return R.ok(centerEventViewService.selectEventList(visuForestCloudMapVO));
    }

    @ApiOperation("查询事件详情")
    @PostMapping("/getEventDetail")
    public R getEventDetail(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventViewService.getEventDetail(visuForestCloudMapVO));
    }

    @ApiOperation("查询当月每日事件数量")
    @PostMapping("/selectEventByCalendar")
    public R selectEventByCalendar(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        List<Map<String, Object>> result = centerEventViewService.selectEventByCalendar(visuForestCloudMapVO);
        return R.ok(completionDate(result, Arrays.asList(), "day", "daycount"));
    }

    @ApiOperation("查询曝光台列表")
    @PostMapping("/selectExposureStage")
    public R selectExposureStage(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        return R.ok(centerEventViewService.selectExposureStage(visuForestCloudMapVO));
    }

    @ApiOperation("查询事件分类数量")
    @PostMapping("/getEventByEventType")
    public R getEventByEventType(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        return R.ok(centerEventViewService.getEventByEventType(visuForestCloudMapVO));
    }

    @ApiOperation("查询上报人排名")
    @PostMapping("/getEventByReportorOrder")
    public R getEventByReportorOrder(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        return R.ok(centerEventViewService.getEventByReportorOrder(visuForestCloudMapVO));
    }

    @ApiOperation("查询附近事件")
    @PostMapping("/getNearEvent")
    public R getNearEvent(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        getParam(visuForestCloudMapVO);
        return R.ok(centerEventViewService.getNearEvent(visuForestCloudMapVO));
    }

    @ApiOperation("事件推送")
    @PostMapping("/eventPush")
    public R eventPush(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        if (StringUtils.isBlank(visuForestCloudMapVO.getEventCode())) {
            return R.fail("请传入事件编号");
        }
        VisuForestEventTodayEventListBO bo = centerEventViewService.eventPush(visuForestCloudMapVO);
        // 是签收状态，直接推送
        if (StringUtils.isNull(bo) || "forest_event_status_2".equals(bo.getEventStatusValue())) {
            return R.ok(bo);
        }
        // 非签收状态，判断是否行管局
        R<Boolean> result = SpringUtils.getBean(RemoteDeptService.class).deptParentsHasBureau(SecurityUtils.getLoginUser().getSysUser().getDeptId());
        if (result.getData()) {
            return R.ok();
        }
        return R.ok(bo);
    }

    public void getParam(VisuForestCloudMapVO visuForestCloudMapVO) {
        // 未配置可视化可见类型，小类给-1不可查
        if (StringUtils.isEmpty(visuForestCloudMapVO.getEventTypeId())) {
            visuForestCloudMapVO.setEventTypeId(new String[]{"-1"});
        }
        // 配置包含火险事件，大类给1，否则给-1无需查询
        String[] dl = visuForestCloudMapVO.getEventTypeIdDl();
        if (ArrayUtils.contains(dl, "1")) {
            visuForestCloudMapVO.setEventTypeIdDl(new String[]{"1"});
        } else {
            visuForestCloudMapVO.setEventTypeIdDl(new String[]{"-1"});
        }
//        R<Boolean> result = SpringUtils.getBean(RemoteDeptService.class).deptParentsHasBureau(SecurityUtils.getLoginUser().getSysUser().getDeptId());
//        visuForestCloudMapVO.setIsHgj(result.getData().toString());
        visuForestCloudMapVO.setIsHgj("false");
    }

    @GetMapping("/listAll")
    public TableDataInfo listAll(VisuForestCloudMapVO visuForestCloudMapVO) {
        startPage();
        return getDataTable(centerEventViewService.listAll(visuForestCloudMapVO));
    }

    /**
     * 住建事件统计
     *
     * @param visuForestCloudMapVO
     * @return
     */
    @PostMapping("/getHousingConstructionEventCount")
    public R getHousingConstructionEventCount(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventViewService.getHousingConstructionEventCount(visuForestCloudMapVO));
    }

    /**
     * 住建事件列表
     *
     * @param visuForestCloudMapVO
     * @return
     */
    @PostMapping("/getHousingConstructionEventList")
    public R getHousingConstructionEventList(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centerEventViewService.getHousingConstructionEventList(visuForestCloudMapVO));
    }
}
