package com.sooka.sponest.event.centereventteventcatalogue.service.impl;

import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.datascope.base.service.BaseService;
import com.sooka.sponest.event.centereventtdeptevent.domain.CentereventDeptEvent;
import com.sooka.sponest.event.centereventteventcatalogue.mapper.CenterEventCommandCenterMapper;
import com.sooka.sponest.event.centereventteventcatalogue.service.ICenterEventCommandCenterService;
import org.apache.commons.collections4.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.*;
import java.util.stream.Collectors;

import static com.sooka.sponest.event.utils.EventConstants.*;

/**
 * 事件中心-市指挥中心Service业务层处理
 *
 * @author lyq
 * @date 2023-04-23
 */
@Service
public class CenterEventCommandCenterServiceImpl extends BaseService implements ICenterEventCommandCenterService {

    @Autowired
    private CenterEventCommandCenterMapper centerEventCommandCenterMapper;

    private static final String NAME = "name";
    private static final String NUMBER = "num";
    private static final String UNPROCESSED = "unprocessed";
    private static final String PROCESSING = "processing";
    private static final String PROCESSED = "processed";
    private static final String MONTH = "month";
    private static final Map<String, List> HGJ_MAP = new HashMap();

    static {
        HGJ_MAP.put(SI_PING, Arrays.asList(367, 3772, 3773, 3774, 3775, 3776, 3777, 3778, 14449));// 四平市行管局
        HGJ_MAP.put(SHUANG_LIAO, Arrays.asList(377, 378, 379, 380, 381, 382, 3809, 384, 14458));// 双辽市行管局
        HGJ_MAP.put(YI_TONG, Arrays.asList(386, 387, 388, 389, 390, 391, 3807, 393, 14459));// 伊通县行管局
        HGJ_MAP.put(LI_SHU, Arrays.asList(401, 402, 403, 404, 405, 406, 3804, 408, 14457));// 梨树县行管局
        HGJ_MAP.put(TIE_DONG, Arrays.asList(416, 417, 418, 419, 420, 421, 3800, 423, 14460));// 铁东区行管局
        HGJ_MAP.put(TIE_XI, Arrays.asList(425, 426, 427, 428, 429, 430, 3796, 432, 14461));// 铁西区行管局
    }

    public List<Map<String, Object>> dataFilter(List<Map<String, Object>> list) {
        // 默认值
        Map<String, Long> defaultMap = new HashMap<>();
        defaultMap.put(SI_PING_NAME, 0L);
        defaultMap.put(SHUANG_LIAO_NAME, 0L);
        defaultMap.put(YI_TONG_NAME, 0L);
        defaultMap.put(LI_SHU_NAME, 0L);
        defaultMap.put(TIE_DONG_NAME, 0L);
        defaultMap.put(TIE_XI_NAME, 0L);
        Map<String, Long> unprocessedMap = new HashMap<>();
        unprocessedMap.put(SI_PING_NAME, 0L);
        unprocessedMap.put(SHUANG_LIAO_NAME, 0L);
        unprocessedMap.put(YI_TONG_NAME, 0L);
        unprocessedMap.put(LI_SHU_NAME, 0L);
        unprocessedMap.put(TIE_DONG_NAME, 0L);
        unprocessedMap.put(TIE_XI_NAME, 0L);
        Map<String, Long> processingMap = new HashMap<>();
        processingMap.put(SI_PING_NAME, 0L);
        processingMap.put(SHUANG_LIAO_NAME, 0L);
        processingMap.put(YI_TONG_NAME, 0L);
        processingMap.put(LI_SHU_NAME, 0L);
        processingMap.put(TIE_DONG_NAME, 0L);
        processingMap.put(TIE_XI_NAME, 0L);
        Map<String, Long> processedMap = new HashMap<>();
        processedMap.put(SI_PING_NAME, 0L);
        processedMap.put(SHUANG_LIAO_NAME, 0L);
        processedMap.put(YI_TONG_NAME, 0L);
        processedMap.put(LI_SHU_NAME, 0L);
        processedMap.put(TIE_DONG_NAME, 0L);
        processedMap.put(TIE_XI_NAME, 0L);
        // sum
        Iterator<Map<String, Object>> iterator = list.iterator();
        Map<String, Object> map = null;
        while (iterator.hasNext()) {
            map = iterator.next();
            if (StringUtils.isNull(MapUtils.getString(map, "ancestors"))) {
                defaultMap.put(SI_PING_NAME, defaultMap.get(SI_PING_NAME) + MapUtils.getLong(map, NUMBER));
                unprocessedMap.put(SI_PING_NAME, unprocessedMap.get(SI_PING_NAME) + MapUtils.getLong(map, UNPROCESSED));
                processingMap.put(SI_PING_NAME, processingMap.get(SI_PING_NAME) + MapUtils.getLong(map, PROCESSING));
                processedMap.put(SI_PING_NAME, processedMap.get(SI_PING_NAME) + MapUtils.getLong(map, PROCESSED));
                continue;
            }
            List<String> ancestors = Arrays.asList(MapUtils.getString(map, "ancestors").split(","));
            if (ancestors.contains(SHUANG_LIAO)) {
                defaultMap.put(SHUANG_LIAO_NAME, defaultMap.get(SHUANG_LIAO_NAME) + MapUtils.getLong(map, NUMBER));
                unprocessedMap.put(SHUANG_LIAO_NAME, unprocessedMap.get(SHUANG_LIAO_NAME) + MapUtils.getLong(map, UNPROCESSED));
                processingMap.put(SHUANG_LIAO_NAME, processingMap.get(SHUANG_LIAO_NAME) + MapUtils.getLong(map, PROCESSING));
                processedMap.put(SHUANG_LIAO_NAME, processedMap.get(SHUANG_LIAO_NAME) + MapUtils.getLong(map, PROCESSED));
            }
            if (ancestors.contains(YI_TONG)) {
                defaultMap.put(YI_TONG_NAME, defaultMap.get(YI_TONG_NAME) + MapUtils.getLong(map, NUMBER));
                unprocessedMap.put(YI_TONG_NAME, unprocessedMap.get(YI_TONG_NAME) + MapUtils.getLong(map, UNPROCESSED));
                processingMap.put(YI_TONG_NAME, processingMap.get(YI_TONG_NAME) + MapUtils.getLong(map, PROCESSING));
                processedMap.put(YI_TONG_NAME, processedMap.get(YI_TONG_NAME) + MapUtils.getLong(map, PROCESSED));
            }
            if (ancestors.contains(LI_SHU)) {
                defaultMap.put(LI_SHU_NAME, defaultMap.get(LI_SHU_NAME) + MapUtils.getLong(map, NUMBER));
                unprocessedMap.put(LI_SHU_NAME, unprocessedMap.get(LI_SHU_NAME) + MapUtils.getLong(map, UNPROCESSED));
                processingMap.put(LI_SHU_NAME, processingMap.get(LI_SHU_NAME) + MapUtils.getLong(map, PROCESSING));
                processedMap.put(LI_SHU_NAME, processedMap.get(LI_SHU_NAME) + MapUtils.getLong(map, PROCESSED));
            }
            if (ancestors.contains(TIE_DONG)) {
                defaultMap.put(TIE_DONG_NAME, defaultMap.get(TIE_DONG_NAME) + MapUtils.getLong(map, NUMBER));
                unprocessedMap.put(TIE_DONG_NAME, unprocessedMap.get(TIE_DONG_NAME) + MapUtils.getLong(map, UNPROCESSED));
                processingMap.put(TIE_DONG_NAME, processingMap.get(TIE_DONG_NAME) + MapUtils.getLong(map, PROCESSING));
                processedMap.put(TIE_DONG_NAME, processedMap.get(TIE_DONG_NAME) + MapUtils.getLong(map, PROCESSED));
            }
            if (ancestors.contains(TIE_XI)) {
                defaultMap.put(TIE_XI_NAME, defaultMap.get(TIE_XI_NAME) + MapUtils.getLong(map, NUMBER));
                unprocessedMap.put(TIE_XI_NAME, unprocessedMap.get(TIE_XI_NAME) + MapUtils.getLong(map, UNPROCESSED));
                processingMap.put(TIE_XI_NAME, processingMap.get(TIE_XI_NAME) + MapUtils.getLong(map, PROCESSING));
                processedMap.put(TIE_XI_NAME, processedMap.get(TIE_XI_NAME) + MapUtils.getLong(map, PROCESSED));
            }
            if (ancestors.contains(SI_PING)) {
                defaultMap.put(SI_PING_NAME, defaultMap.get(SI_PING_NAME) + MapUtils.getLong(map, NUMBER));
                unprocessedMap.put(SI_PING_NAME, unprocessedMap.get(SI_PING_NAME) + MapUtils.getLong(map, UNPROCESSED));
                processingMap.put(SI_PING_NAME, processingMap.get(SI_PING_NAME) + MapUtils.getLong(map, PROCESSING));
                processedMap.put(SI_PING_NAME, processedMap.get(SI_PING_NAME) + MapUtils.getLong(map, PROCESSED));
            }
        }
        List<Map<String, Object>> result = new ArrayList<>();
        for (Map.Entry<String, Long> entry : defaultMap.entrySet()) {
            String[] keys = entry.getKey().split("_");
            // 不要四平市
            if (!SI_PING.equals(keys[0])) {
                map = new HashMap<>();
                map.put(NAME, keys[1]);
                map.put(NUMBER, entry.getValue());
                map.put(UNPROCESSED, unprocessedMap.get(entry.getKey()));
                map.put(PROCESSING, processingMap.get(entry.getKey()));
                map.put(PROCESSED, processedMap.get(entry.getKey()));
                result.add(map);
            }
        }
        Collections.sort(result, (o2, o1) -> MapUtils.getLong(o1, NUMBER).compareTo(MapUtils.getLong(o2, NUMBER)));
        return result;
    }

    @Override
    public List<Map<String, Object>> getDeptEventCount(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        List<Map<String, Object>> result = centerEventCommandCenterMapper.getDeptEventCount(centereventTDeptEvent);
        if (SI_PING.equals(String.valueOf(centereventTDeptEvent.getDeptId()))) {
            result = dataFilter(result);
        }
        return result;
    }

    @Override
    public List<Map<String, Object>> getFireSource(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        return centerEventCommandCenterMapper.getFireSource(centereventTDeptEvent);
    }

    @Override
    public List<Map<String, Object>> getFirePlace(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        return centerEventCommandCenterMapper.getFirePlace(centereventTDeptEvent);
    }

    @Override
    public List<Map<String, Object>> getFireLoss(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        List<Map<String, Object>> result = centerEventCommandCenterMapper.getFireLoss(centereventTDeptEvent);
        // 提取已存在的年-月
        List<String> originDate = result.stream().map(item -> MapUtils.getString(item, MONTH)).collect(Collectors.toList());
        // 获取不存在的年-月
        int year = LocalDate.now().getYear();
        List<String> newDate = Arrays.asList(year + "-01", year + "-02", year + "-03", year + "-04", year + "-05", year + "-06", year + "-07", year + "-08", year + "-09", year + "-10", year + "-11", year + "-12");
        newDate = newDate.stream().filter(o -> !originDate.contains(o)).collect(Collectors.toList());
        newDate.forEach(date -> {
            Map<String, Object> map = new HashMap<>();
            map.put(MONTH, date);
            map.put("loss", 0L);
            map.put("blazes", 0L);
            result.add(map);
        });
        // 排序
        Collections.sort(result, (o1, o2) -> MapUtils.getString(o1, MONTH).compareTo(MapUtils.getString(o2, MONTH)));
        return result;
    }

    @Override
    public List<Map<String, Object>> getFireInfo(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        return centerEventCommandCenterMapper.getFireInfo(centereventTDeptEvent);
    }

    @Override
    public List<Map<String, Object>> getEventStatusCount(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        return centerEventCommandCenterMapper.getEventStatusCount(centereventTDeptEvent);
    }

    @Override
    public List<Map<String, Object>> getEventTypeCount(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        return centerEventCommandCenterMapper.getEventTypeCount(centereventTDeptEvent);
    }

    @Override
    public List<Map<String, Object>> getEventHgjCount(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        List hgjList = HGJ_MAP.get(String.valueOf(centereventTDeptEvent.getDeptId()));
        if (StringUtils.isEmpty(hgjList)) {// 非三县两区用户，默认返四平市
            hgjList = HGJ_MAP.get(SI_PING);
        }
        centereventTDeptEvent.getParams().put("hgj", hgjList);
        return centerEventCommandCenterMapper.getEventHgjCount(centereventTDeptEvent);
    }

    @Override
    public List<Map<String, Object>> getEventTrend(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        List<Map<String, Object>> result = centerEventCommandCenterMapper.getEventTrend(centereventTDeptEvent);
        // 提取已存在的年-月
        List<String> originDate = result.stream().map(item -> MapUtils.getString(item, NAME)).collect(Collectors.toList());
        // 获取不存在的年-月
        int year = LocalDate.now().getYear();
        List<String> newDate = Arrays.asList(year + "-01", year + "-02", year + "-03", year + "-04", year + "-05", year + "-06", year + "-07", year + "-08", year + "-09", year + "-10", year + "-11", year + "-12");
        newDate = newDate.stream().filter(o -> !originDate.contains(o)).collect(Collectors.toList());
        newDate.forEach(date -> {
            Map<String, Object> map = new HashMap<>();
            map.put(NAME, date);
            map.put("num", 0L);
            result.add(map);
        });
        // 排序
        Collections.sort(result, (o1, o2) -> MapUtils.getString(o1, NAME).compareTo(MapUtils.getString(o2, NAME)));
        return result;
    }

    @Override
    public List<Map<String, Object>> getEventBmCount(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        List<Map<String, Object>> result = centerEventCommandCenterMapper.getEventBmCount(centereventTDeptEvent);
        if (SI_PING.equals(String.valueOf(centereventTDeptEvent.getDeptId()))) {
            result = dataFilter(result);
        }
        return result.stream().filter(item -> StringUtils.isNotEmpty(MapUtils.getString(item, NAME))).collect(Collectors.toList());
    }

    @Override
    public List<Map<String, Object>> getEventPoint(CentereventDeptEvent centereventTDeptEvent) {
        setSookaDataBase(centereventTDeptEvent);
        return centerEventCommandCenterMapper.getEventPoint(centereventTDeptEvent);
    }
}
