package com.sooka.sponest.event.centereventteventtype.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.centereventteventtype.domain.CentereventTEventtype;
import com.sooka.sponest.event.centereventteventtype.service.ICentereventTEventtypeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 事件类型Controller
 *
 * @author ruoyi
 * @date 2022-08-27
 */
@Api(tags = "事件类型")
@RestController
@RequestMapping("/eventtype")
public class CentereventTEventtypeController extends BaseController {

    @Autowired
    private ICentereventTEventtypeService centereventTEventtypeService;

    /**
     * 查询事件类型列表
     */
    @RequiresPermissions("eventtype:eventtype:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTEventtype centereventTEventtype) {
        startPage();
        List<CentereventTEventtype> list = centereventTEventtypeService.selectCentereventTEventtypeList(centereventTEventtype);
        for (CentereventTEventtype type : list) {
            dateChange(type);
        }
        return getDataTable(list);
    }

    private void dateChange(CentereventTEventtype type) {
        long reminderTimeDay = Long.parseLong(type.getReminderTime()) / 1440;
        long reminderTimeHour = (Long.parseLong(type.getReminderTime()) % 1440) / 60;
        long reminderTimeMinute = (Long.parseLong(type.getReminderTime()) % 1440) % 60;
        type.setReminderTimeDay(String.valueOf(reminderTimeDay));
        type.setReminderTimeHour(String.valueOf(reminderTimeHour));
        type.setReminderTimeMinute(String.valueOf(reminderTimeMinute));
        String reminderTime;
        if (reminderTimeDay != 0) {
            reminderTime = reminderTimeDay + "天" + reminderTimeHour + "时" + reminderTimeMinute + "分";
        } else if (reminderTimeHour != 0) {
            reminderTime = reminderTimeHour + "时" + reminderTimeMinute + "分";
        } else {
            reminderTime = reminderTimeMinute + "分";
        }
        type.setReminderTime(reminderTime);
    }

    /**
     * 查询事件类型列表
     */
    @ApiOperation("查询事件类型列表")
    @GetMapping("/getCentereventTEventtypeByParentId")
    public R getCentereventTEventtypeByParentId(CentereventTEventtype centereventTEventtype) {
        return R.ok(centereventTEventtypeService.selectCentereventTEventtypeList(centereventTEventtype));
    }

    /**
     * 导出事件类型列表
     */
    @RequiresPermissions("eventtype:eventtype:export")
    @Log(title = "事件类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTEventtype centereventTEventtype) {
        List<CentereventTEventtype> list = centereventTEventtypeService.selectCentereventTEventtypeList(centereventTEventtype);
        ExcelUtil<CentereventTEventtype> util = new ExcelUtil<>(CentereventTEventtype.class);
        util.exportExcel(response, list, "事件类型数据");
    }

    /**
     * 获取事件类型详细信息
     */
    @RequiresPermissions("eventtype:eventtype:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        CentereventTEventtype type = centereventTEventtypeService.selectCentereventTEventtypeById(id);
        dateChange(type);
        return AjaxResult.success(type);
    }

    /**
     * 新增事件类型
     */
    @RequiresPermissions("eventtype:eventtype:add")
    @Log(title = "事件类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CentereventTEventtype centereventTEventtype) {
        int num = centereventTEventtypeService.insertCentereventTEventtype(centereventTEventtype);
        if (num == 0) {
            return AjaxResult.error("催办时间不能为0!");
        }
        return AjaxResult.success();
    }

    /**
     * 修改事件类型
     */
    @RequiresPermissions("eventtype:eventtype:edit")
    @Log(title = "事件类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTEventtype centereventTEventtype) {
        int num = centereventTEventtypeService.updateCentereventTEventtype(centereventTEventtype);
        if (num == 0) {
            return AjaxResult.error("催办时间不能为0!");
        }
        return AjaxResult.success();
    }

    /**
     * 删除事件类型
     */
    @RequiresPermissions("eventtype:eventtype:remove")
    @Log(title = "事件类型", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTEventtypeService.deleteCentereventTEventtypeByIds(ids));
    }

    /**
     * 事件类型树结构
     *
     * @author hanfucheng
     * @date 2023/4/10 10:50
     */
    @ApiOperation("查询事件类型树结构")
    @GetMapping("/getCentereventTEventtypeTree")
    public R getCentereventTEventtypeTree() {
        return R.ok(centereventTEventtypeService.getCentereventTEventtypeTree());
    }

    /**
     * 事件类型树结构
     *
     * @author hanfucheng
     * @date 2023/4/10 10:50
     */
    @ApiOperation("查询事件类型小类树结构")
    @GetMapping("/getCentereventTEventtypeTreeLx")
    public R getCentereventTEventtypeTreeLx(CentereventTEventtype centereventTEventtype) {
        return R.ok(centereventTEventtypeService.getCentereventTEventtypeTreeLx(centereventTEventtype));
    }
}
