package com.sooka.sponest.event.centereventteventtype.service.impl;

import com.sooka.sponest.event.centereventteventcatalogue.domain.CentereventTEventcatalogue;
import com.sooka.sponest.event.centereventteventtype.domain.CentereventTEventtype;
import com.sooka.sponest.event.centereventteventtype.mapper.CentereventTEventtypeMapper;
import com.sooka.sponest.event.centereventteventtype.service.ICentereventTEventtypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 事件类型Service业务层处理
 *
 * @author ruoyi
 * @date 2022-08-27
 */
@Service
public class CentereventTEventtypeServiceImpl implements ICentereventTEventtypeService {

    @Autowired
    private CentereventTEventtypeMapper centereventTEventtypeMapper;

    static final String VALUE = "value";
    static final String LABEL = "label";
    static final String ID = "id";
    static final String EVENT_TYPE_NAME = "event_type_name";

    /**
     * 查询事件类型列表
     *
     * @param centereventTEventtype 事件类型
     * @return 事件类型
     */
    @Override
    public List<CentereventTEventtype> selectCentereventTEventtypeList(CentereventTEventtype centereventTEventtype) {
        return centereventTEventtypeMapper.selectCentereventTEventtypeList(centereventTEventtype);
    }

    /**
     * 查询事件类型
     *
     * @param id 事件类型主键
     * @return 事件类型
     */
    @Override
    public CentereventTEventtype selectCentereventTEventtypeById(String id) {
        return centereventTEventtypeMapper.selectCentereventTEventtypeById(id);
    }

    /**
     * 查询事件类型
     *
     * @param code 事件类型编码
     * @return 事件类型
     */
    @Override
    public CentereventTEventtype selectCentereventTEventtypeByCode(String code) {
        return centereventTEventtypeMapper.selectCentereventTEventtypeByCode(code);
    }

    /**
     * 查询事件类型
     *
     * @param code 事件类型编码
     * @return 事件类型
     */
    @Override
    public CentereventTEventtype selectCentereventTEventtypeByCodeTower(String code) {
        return centereventTEventtypeMapper.selectCentereventTEventtypeByCodeTower(code);
    }

    /**
     * 新增事件类型
     *
     * @param centereventTEventtype 事件类型
     * @return 结果
     */
    @Transactional
    @Override
    public int insertCentereventTEventtype(CentereventTEventtype centereventTEventtype) {
        if (datechange(centereventTEventtype)) return 0;
        return centereventTEventtypeMapper.insertCentereventTEventtype(centereventTEventtype);
    }

    /**
     * 修改事件类型
     *
     * @param centereventTEventtype 事件类型
     * @return 结果
     */
    @Transactional
    @Override
    public int updateCentereventTEventtype(CentereventTEventtype centereventTEventtype) {
        if (datechange(centereventTEventtype)) return 0;
        return centereventTEventtypeMapper.updateCentereventTEventtype(centereventTEventtype);
    }

    private boolean datechange(CentereventTEventtype centereventTEventtype) {
        long reminderTimeDay = Long.parseLong(("").equals(centereventTEventtype.getReminderTimeDay()) ? "0" : centereventTEventtype.getReminderTimeDay()) * 24 * 60;
        long reminderTimeHour = Long.parseLong(("").equals(centereventTEventtype.getReminderTimeHour()) ? "0" : centereventTEventtype.getReminderTimeHour()) * 60;
        long reminderTime = reminderTimeDay + reminderTimeHour + Long.parseLong(("").equals(centereventTEventtype.getReminderTimeMinute()) ? "0" : centereventTEventtype.getReminderTimeMinute());
        if (reminderTime == 0) {
            return true;
        }
        centereventTEventtype.setReminderTime(String.valueOf(reminderTime));
        return false;
    }

    /**
     * 批量删除事件类型
     *
     * @param ids 需要删除的事件类型主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteCentereventTEventtypeByIds(String[] ids) {
        return centereventTEventtypeMapper.deleteCentereventTEventtypeByIds(ids);
    }

    @Override
    public List<Map<String, Object>> getCentereventTEventtypeTreeLx(CentereventTEventtype centereventTEventtype) {
        List<Map<String, Object>> bigList = new ArrayList<>();
        List<Map<String, Object>> mapList = centereventTEventtypeMapper.getCentereventTEventtypeTreeLx(centereventTEventtype);
        for (Map<String, Object> map : mapList) {
            Map<String, Object> bigType = new HashMap<>();
            bigType.put(VALUE, map.get(ID));
            bigType.put(LABEL, map.get(EVENT_TYPE_NAME));
            bigList.add(bigType);
        }
        return bigList;
    }

    /**
     * 查询事件类型树结构
     *
     * @author hanfucheng
     * @date 2023/4/10 10:54
     */
    @Override
    public List<Map<String, Object>> getCentereventTEventtypeTree() {
        List<Map<String, Object>> bigList = new ArrayList<>();
        List<Map<String, Object>> mapList = centereventTEventtypeMapper.getCentereventTEventtypeTree();
        for (Map<String, Object> map : mapList) {
            if ("0".equals(map.get("parent_id"))) {
                Map<String, Object> bigType = new HashMap<>();
                List<Map<String, Object>> smallList = new ArrayList<>();
                bigType.put(VALUE, map.get(ID));
                bigType.put(LABEL, map.get(EVENT_TYPE_NAME));
                for (Map<String, Object> map1 : mapList) {
                    if (map1.get("parent_id").equals(map.get(ID).toString())) {
                        Map<String, Object> smallType = new HashMap<>();
                        smallType.put(VALUE, map1.get(ID));
                        smallType.put(LABEL, map1.get(EVENT_TYPE_NAME));
                        smallList.add(smallType);
                    }
                }
                bigType.put("children", smallList);
                bigList.add(bigType);
            }
        }
        return bigList;
    }

    @Override
    public long getReminderTimeById(CentereventTEventcatalogue centereventTEventcatalogue) {
        return centereventTEventtypeMapper.getReminderTimeById(centereventTEventcatalogue);
    }
}
