package com.sooka.sponest.event.centereventteventtypemonitor.controller;

import com.alibaba.fastjson.JSON;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.centereventteventcatalogue.domain.vo.VisuForestCloudMapVO;
import com.sooka.sponest.event.centereventteventtypemonitor.domain.CentereventTEventtypeMonitor;
import com.sooka.sponest.event.centereventteventtypemonitor.service.ICentereventTEventtypemonitorService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @Auther: mjq
 * @Date: 2023/7/1 - 07 - 01 - 8:58
 * @Description: com.sooka.sponest.event.centereventteventtypemonitor.controller
 * @version: 1.0
 */
@Api(tags = "事件类型模版")
@RestController
@RequestMapping("/eventtypemonitor")
public class CentereventTEventtypeMonitorController extends BaseController {

    @Autowired
    private ICentereventTEventtypemonitorService centereventTEventtypemonitorService;

    /**
     * 查询事件模版类型列表
     */
    @RequiresPermissions("eventtypemonitor:eventtypemonitor:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTEventtypeMonitor centereventTEventtypeMonitor) {
        startPage();
        List<CentereventTEventtypeMonitor> list = centereventTEventtypemonitorService.selectCentereventTEventtypeMonitorList(centereventTEventtypeMonitor);
        return getDataTable(list);
    }

    @GetMapping("/listByParentId")
    public R listByParentId(CentereventTEventtypeMonitor centereventTEventtypeMonitor) {
        return R.ok(centereventTEventtypemonitorService.selectCentereventTEventtypeMonitorList(centereventTEventtypeMonitor));
    }

    /**
     * 导出事件模版类型列表
     */
    @RequiresPermissions("eventtypemonitor:eventtypemonitor:export")
    @Log(title = "事件模版类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTEventtypeMonitor centereventTEventtypeMonitor) {
        List<CentereventTEventtypeMonitor> list = centereventTEventtypemonitorService.selectCentereventTEventtypeMonitorList(centereventTEventtypeMonitor);
        ExcelUtil<CentereventTEventtypeMonitor> util = new ExcelUtil<>(CentereventTEventtypeMonitor.class);
        util.exportExcel(response, list, "事件模版类型数据");
    }

    /**
     * 获取事件模版类型详细信息
     */
    @RequiresPermissions("eventtypemonitor:eventtypemonitor:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(centereventTEventtypemonitorService.selectCentereventTEventtypeMonitorById(id));
    }

    /**
     * 新增事件模版类型
     */
    @RequiresPermissions("eventtypemonitor:eventtypemonitor:add")
    @Log(title = "事件模版类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CentereventTEventtypeMonitor centereventTEventtypeMonitor) {
        centereventTEventtypeMonitor.setParentId(0L);
        return toAjax(centereventTEventtypemonitorService.insertCentereventTEventtypeMonitor(centereventTEventtypeMonitor));
    }

    /**
     * 修改事件模版类型
     */
    @RequiresPermissions("eventtypemonitor:eventtypemonitor:edit")
    @Log(title = "事件模版类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTEventtypeMonitor centereventTEventtypeMonitor) {
        return toAjax(centereventTEventtypemonitorService.updateCentereventTEventtypeMonitor(centereventTEventtypeMonitor));
    }

    /**
     * 删除事件模版类型
     */
    @RequiresPermissions("eventtypemonitor:eventtypemonitor:remove")
    @Log(title = "事件模版类型", businessType = BusinessType.DELETE)
    @DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id) {
        return toAjax(centereventTEventtypemonitorService.deleteCentereventTEventtypeMonitorById(id));
    }

    @ApiOperation("查询事件类型模版树结构")
    @GetMapping("/getCentereventTEventtypemonitorTree/{templateType}")
    public R getCentereventTEventtypemonitorTree(@PathVariable("templateType") String templateType) {
        return R.ok(centereventTEventtypemonitorService.getCentereventTEventtypemonitorTree(templateType));
    }

    @RequiresPermissions("eventtypemonitor:eventtypemonitor:add")
    @Log(title = "事件类型增加小类", businessType = BusinessType.INSERT)
    @PostMapping("/saveTypelx")
    public AjaxResult saveTypelx(@RequestBody String data) {
        List<CentereventTEventtypeMonitor> centereventTEventtypeMonitors = JSON.parseArray(data, CentereventTEventtypeMonitor.class);
        return toAjax(centereventTEventtypemonitorService.saveTypelx(centereventTEventtypeMonitors));
    }

    @ApiOperation("查询事件模版分类数量")
    @PostMapping("/getEventByEventTypemonitor")
    public R getEventByEventTypemonitor(@RequestBody VisuForestCloudMapVO visuForestCloudMapVO) {
        return R.ok(centereventTEventtypemonitorService.getEventByEventType(visuForestCloudMapVO));
    }
}
