package com.sooka.sponest.event.centereventtfireevent.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.centereventteventcatalogue.domain.vo.VisuForestCloudMapVO;
import com.sooka.sponest.event.centereventtfireevent.domain.CentereventTFireEvent;
import com.sooka.sponest.event.centereventtfireevent.service.ICentereventTFireEventService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 火险事件扩展Controller
 *
 * @author 朱哲
 * @date 2022-08-29
 */
@Api(tags = "火险事件扩展")
@RestController
@RequestMapping("/centereventtfireevent")
public class CentereventTFireEventController extends BaseController {

    @Autowired
    private ICentereventTFireEventService centereventTFireEventService;

    /**
     * 查询火险事件扩展列表
     */
    @RequiresPermissions("centereventtfireevent:centereventtfireevent:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTFireEvent centereventTFireEvent) {
        startPage();
        List<CentereventTFireEvent> list = centereventTFireEventService.selectCentereventTFireEventList(centereventTFireEvent);
        return getDataTable(list);
    }

    /**
     * 查询火险事件扩展列表
     */
    @ApiOperation("查询火险事件扩展列表")
    @GetMapping("/getAllCentereventTFireEvent")
    public R getAllCentereventTFireEvent(CentereventTFireEvent centereventTFireEvent) {
        return R.ok(centereventTFireEventService.selectCentereventTFireEventList(centereventTFireEvent));
    }

    /**
     * 导出火险事件扩展列表
     */
    @RequiresPermissions("centereventtfireevent:centereventtfireevent:export")
    @Log(title = "火险事件扩展", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTFireEvent centereventTFireEvent) {
        List<CentereventTFireEvent> list = centereventTFireEventService.selectCentereventTFireEventList(centereventTFireEvent);
        ExcelUtil<CentereventTFireEvent> util = new ExcelUtil<>(CentereventTFireEvent.class);
        util.exportExcel(response, list, "火险事件扩展数据");
    }

    /**
     * 新增火险事件扩展
     */
    @RequiresPermissions("centereventtfireevent:centereventtfireevent:add")
    @Log(title = "火险事件扩展", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CentereventTFireEvent centereventTFireEvent) {
        return toAjax(centereventTFireEventService.insertCentereventTFireEvent(centereventTFireEvent));
    }

    /**
     * 修改火险事件扩展
     */
    @ApiOperation("修改火险事件扩展")
    @Log(title = "火险事件扩展", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTFireEvent centereventTFireEvent) {
        int result = 0;
        if (StringUtils.isNotBlank(centereventTFireEvent.getEventCode())) {
            CentereventTFireEvent fireEvent = centereventTFireEventService.selectCentereventTFireEventByEventCode(centereventTFireEvent.getEventCode());
            try {
                if (null == fireEvent) {
                    result = centereventTFireEventService.insertCentereventTFireEvent(centereventTFireEvent);
                } else {
                    result = centereventTFireEventService.updateCentereventTFireEvent(centereventTFireEvent);
                }
            } catch (Exception e) {
                logger.error(e.getMessage());
            }
        }
        return toAjax(result);
    }

    /**
     * 删除火险事件扩展
     */
    @RequiresPermissions("centereventtfireevent:centereventtfireevent:remove")
    @Log(title = "火险事件扩展", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTFireEventService.deleteCentereventTFireEventByIds(ids));
    }


    /**
     * 获取预案信息
     */
    @ApiOperation("获取预案信息")
    @GetMapping("/getYuAnByEventCode")
    public R getYuAnByEventCode(VisuForestCloudMapVO visuForestCloudMapVO) {
        if (StringUtils.isBlank(visuForestCloudMapVO.getEventCode())) {
            return R.fail();
        }
        return R.ok(centereventTFireEventService.getYuAnByEventCode(visuForestCloudMapVO));
    }
}
