package com.sooka.sponest.event.centereventtfirelog.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.file.FilePrefixUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.sooka.sponest.event.centereventtfirelog.domain.CentereventTFireLog;
import com.sooka.sponest.event.centereventtfirelog.service.ICentereventTFireLogService;
import com.sooka.sponest.event.remoteapi.RemoteDataService;
import com.sooka.sponest.event.remoteapi.domain.CenterdataTAttach;
import com.sooka.sponest.event.utils.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 事件操作日志Controller
 *
 * @author 朱哲
 * @date 2022-08-29
 */
@Api(tags = "事件操作日志")
@RestController
@RequestMapping("/centereventtfirelog")
public class CentereventTFireLogController extends BaseController {

    @Autowired
    private ICentereventTFireLogService centereventTFireLogService;

    @Autowired
    private RemoteDataService remoteDataService;

    /**
     * 查询事件操作日志列表
     */
    @RequiresPermissions("centereventtfireLog:centereventtfireLog:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTFireLog centereventTFireLog) {
        startPage();
        List<CentereventTFireLog> list = centereventTFireLogService.selectCentereventTFireLogList(centereventTFireLog);
        return getDataTable(list);
    }

    /**
     * 查询事件操作日志列表
     */
    @ApiOperation("查询事件操作日志列表")
    @GetMapping("/getAllCentereventTFireLog")
    public R getAllCentereventTFireLog(CentereventTFireLog centereventTFireLog) {
        startPage();
        return R.ok(centereventTFireLogService.selectCentereventTFireLogList(centereventTFireLog));
    }

    /**
     * 导出事件操作日志列表
     */
    @RequiresPermissions("centereventtfireLog:centereventtfireLog:export")
    @Log(title = "事件操作日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTFireLog centereventTFireLog) {
        List<CentereventTFireLog> list = centereventTFireLogService.selectCentereventTFireLogList(centereventTFireLog);
        ExcelUtil<CentereventTFireLog> util = new ExcelUtil<>(CentereventTFireLog.class);
        util.exportExcel(response, list, "事件操作日志数据");
    }

    /**
     * 获取事件操作日志详细信息
     */
    @ApiOperation("获取事件操作日志详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(centereventTFireLogService.selectCentereventTFireLogById(id));
    }

    /**
     * 获取首条事件操作日志详细信息
     */
    @ApiOperation("获取首条事件操作日志详细信息")
    @GetMapping("/getFirstCentereventTFireLog")
    public R getFirstCentereventTFireLog(String eventCode) {
        if (StringUtils.isBlank(eventCode)) {
            return R.fail("请检查必输项!");
        }
        return R.ok(centereventTFireLogService.selectFirstCentereventTFireLogByEventCode(eventCode));
    }

    /**
     * 新增事件操作日志
     */
//    @RequiresPermissions("centereventtfireLog:centereventtfireLog:add")
    @ApiOperation("新增事件操作日志")
    @Log(title = "事件操作日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody CentereventTFireLog centereventTFireLog) {
        if (StringUtils.isBlank(centereventTFireLog.getId())) {
            centereventTFireLog.setId(IdUtils.simpleUUID());
        }
        int result = 0;
        try {
            if (StringUtils.isNotEmpty(centereventTFireLog.getFileList())) {
                if (StringUtils.isBlank(centereventTFireLog.getLogContent())) {
                    centereventTFireLog.setLogContent(SecurityUtils.getLoginUser().getSysUser().getNickName() + "  " + DateUtils.getTime() + "上传附件");
                }
                for (CenterdataTAttach centerdataTAttach : centereventTFireLog.getFileList()) {
                    centerdataTAttach.setBusId(centereventTFireLog.getId());
                    centerdataTAttach.setBusIndx("bus_indx_forest");
                    centerdataTAttach.setFileType(FilePrefixUtils.getUrlSuffix(centerdataTAttach.getAttachPath()));
                    remoteDataService.insertAttach(centerdataTAttach);
                }
            }
            result = centereventTFireLogService.insertCentereventTFireLog(centereventTFireLog);
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return toAjax(result);
    }

    /**
     * 修改事件操作日志
     */
    @RequiresPermissions("centereventtfireLog:centereventtfireLog:edit")
    @Log(title = "事件操作日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTFireLog centereventTFireLog) {
        return toAjax(centereventTFireLogService.updateCentereventTFireLog(centereventTFireLog));
    }

    /**
     * 删除事件操作日志
     */
    @RequiresPermissions("centereventtfireLog:centereventtfireLog:remove")
    @Log(title = "事件操作日志", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTFireLogService.deleteCentereventTFireLogByIds(ids));
    }
}
