package com.sooka.sponest.event.centereventtfirelog.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.system.api.model.LoginUser;
import com.sooka.sponest.event.centereventtfirelog.domain.CentereventTFireLog;
import com.sooka.sponest.event.centereventtfirelog.mapper.CentereventTFireLogMapper;
import com.sooka.sponest.event.centereventtfirelog.service.ICentereventTFireLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * L
 * 事件操作日志Service业务层处理
 *
 * @author 朱哲
 * @date 2022-08-29
 */
@Service
public class CentereventTFireLogServiceImpl implements ICentereventTFireLogService {

    @Autowired
    private CentereventTFireLogMapper centereventTFireLogMapper;

    /**
     * 查询事件操作日志列表
     *
     * @param centereventTFireLog 事件操作日志
     * @return 事件操作日志
     */
    @Override
    public List<CentereventTFireLog> selectCentereventTFireLogList(CentereventTFireLog centereventTFireLog) {
        return centereventTFireLogMapper.selectCentereventTFireLogList(centereventTFireLog);
    }

    /**
     * 查询事件操作日志
     *
     * @param id 事件操作日志主键
     * @return 事件操作日志
     */
    @Override
    public CentereventTFireLog selectCentereventTFireLogById(String id) {
        return centereventTFireLogMapper.selectCentereventTFireLogById(id);
    }

    /**
     * 查询事件操作日志
     *
     * @param eventCode 事件编号
     * @return 事件操作日志
     */
    @Override
    public CentereventTFireLog selectFirstCentereventTFireLogByEventCode(String eventCode) {
        return centereventTFireLogMapper.selectFirstCentereventTFireLogByEventCode(eventCode);
    }

    /**
     * 新增事件操作日志
     *
     * @param centereventTFireLog 事件操作日志
     * @return 结果
     */
    @Transactional
    @Override
    public int insertCentereventTFireLog(CentereventTFireLog centereventTFireLog) {
        if (null == centereventTFireLog.getCreateName()) {// AI上报已赋值
            centereventTFireLog.setCreateBy(SecurityUtils.getUserId().toString());
            centereventTFireLog.setCreateName(SecurityUtils.getLoginUser().getSysUser().getNickName());
            centereventTFireLog.setCreateTime(DateUtils.getNowDate());
        }
        // modify by reason 所有插入的日志内容统一增加部门
        LoginUser user = SecurityUtils.getLoginUser();
        if (null != user) {// 摄像头新上报事件无法获取部门
            centereventTFireLog.setLogContent(user.getSysUser().getDeptNames() + centereventTFireLog.getLogContent());
        }
        return centereventTFireLogMapper.insertCentereventTFireLog(centereventTFireLog);
    }

    /**
     * 修改事件操作日志
     *
     * @param centereventTFireLog 事件操作日志
     * @return 结果
     */
    @Transactional
    @Override
    public int updateCentereventTFireLog(CentereventTFireLog centereventTFireLog) {
        return centereventTFireLogMapper.updateCentereventTFireLog(centereventTFireLog);
    }

    /**
     * 批量删除事件操作日志
     *
     * @param ids 需要删除的事件操作日志主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteCentereventTFireLogByIds(String[] ids) {
        return centereventTFireLogMapper.deleteCentereventTFireLogByIds(ids);
    }
}
