package com.sooka.sponest.event.centereventtfirespread.controller;

import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.centereventtfirespread.domain.CentereventTFireSpread;
import com.sooka.sponest.event.centereventtfirespread.service.ICentereventTFireSpreadService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 火灾蔓延Controller
 *
 * @author ruoyi
 * @date 2023-04-30
 */
@RestController
@RequestMapping("/spread")
public class CentereventTFireSpreadController extends BaseController {

    @Autowired
    private ICentereventTFireSpreadService centereventTFireSpreadService;

    /**
     * 查询火灾蔓延列表
     */
    @RequiresPermissions("spread:spread:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTFireSpread centereventTFireSpread) {
        startPage();
        List<CentereventTFireSpread> list = centereventTFireSpreadService.selectCentereventTFireSpreadList(centereventTFireSpread);
        return getDataTable(list);
    }

    /**
     * 导出火灾蔓延列表
     */
    @RequiresPermissions("spread:spread:export")
    @Log(title = "火灾蔓延", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTFireSpread centereventTFireSpread) {
        List<CentereventTFireSpread> list = centereventTFireSpreadService.selectCentereventTFireSpreadList(centereventTFireSpread);
        ExcelUtil<CentereventTFireSpread> util = new ExcelUtil<>(CentereventTFireSpread.class);
        util.exportExcel(response, list, "火灾蔓延数据");
    }

    /**
     * 获取火灾蔓延详细信息
     */
    @RequiresPermissions("spread:spread:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(centereventTFireSpreadService.selectCentereventTFireSpreadById(id));
    }

    /**
     * 获取当日火灾蔓延信息
     */
    @GetMapping("/getFireSpreadInfo")
    public AjaxResult getFireSpreadInfo() {
        return AjaxResult.success(centereventTFireSpreadService.getFireSpreadInfo());
    }

    /**
     * 新增火灾蔓延
     */
//    @RequiresPermissions("spread:spread:add")
    @Log(title = "火灾蔓延", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CentereventTFireSpread centereventTFireSpread) {
        return toAjax(centereventTFireSpreadService.insertCentereventTFireSpread(centereventTFireSpread));
    }

    /**
     * 修改火灾蔓延
     */
    @RequiresPermissions("spread:spread:edit")
    @Log(title = "火灾蔓延", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTFireSpread centereventTFireSpread) {
        return toAjax(centereventTFireSpreadService.updateCentereventTFireSpread(centereventTFireSpread));
    }

    /**
     * 删除火灾蔓延
     */
    @RequiresPermissions("spread:spread:remove")
    @Log(title = "火灾蔓延", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTFireSpreadService.deleteCentereventTFireSpreadByIds(ids));
    }

    /**
     * 根据日期获取最新数据
     */
    @GetMapping("/getNewDataByDate")
    public AjaxResult getNewDataByDate(String Date){
        return AjaxResult.success(centereventTFireSpreadService.getNewDataByDate(Date));
    }
}
