package com.sooka.sponest.event.centereventtlog.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.centereventtlog.domain.CentereventTLog;
import com.sooka.sponest.event.centereventtlog.service.ICentereventTLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 事件操作日志Controller
 *
 * @author ruoyi
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/event/system/log")
public class CentereventTLogController extends BaseController
{
    @Autowired
    private ICentereventTLogService centereventTLogService;

    /**
     * 查询事件操作日志列表
     */
    @RequiresPermissions("log:log:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTLog centereventTLog)
    {
        startPage();
        List<CentereventTLog> list = centereventTLogService.selectCentereventTLogList(centereventTLog);
        return getDataTable(list);
    }

    /**
     * 查询事件操作日志列表
     * @Version 1.0
     * @author wang_xy
     * @since 2023/1/6 13:14
     */
    @GetMapping("/listapp")
    public R<Map<String,Object>> listapp(CentereventTLog centereventTLog)
    {
        startPage();
        Map<String,Object> map =  new HashMap<>();
        List<CentereventTLog> list = centereventTLogService.selectCentereventTLogList(centereventTLog);
        map.put("list",getDataTable(list));
        return R.ok(map);
    }

    /**
     * 查询事件编码操作日志列表
     */
    @GetMapping("/listByEventCode/{eventCode}")
    public AjaxResult listByEventCode(@PathVariable String eventCode)
    {
        CentereventTLog centereventTLog=new CentereventTLog();
        centereventTLog.setEventCode(eventCode);
        return AjaxResult.success(centereventTLogService.selectCentereventTLogList(centereventTLog));
    }
    @GetMapping("/selectCentereventTLogListPC/{eventCode}")
    public AjaxResult selectCentereventTLogListPC(@PathVariable String eventCode)
    {
        CentereventTLog centereventTLog=new CentereventTLog();
        centereventTLog.setEventCode(eventCode);
        return AjaxResult.success(centereventTLogService.selectCentereventTLogListPC(centereventTLog));
    }
    /**
     * 导出事件操作日志列表
     */
    @RequiresPermissions("log:log:export")
    @Log(title = "事件操作日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTLog centereventTLog)
    {
        List<CentereventTLog> list = centereventTLogService.selectCentereventTLogList(centereventTLog);
        ExcelUtil<CentereventTLog> util = new ExcelUtil<>(CentereventTLog.class);
        util.exportExcel(response, list, "事件操作日志数据");
    }

    /**
     * 获取事件操作日志详细信息
     */
    @RequiresPermissions("log:log:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(centereventTLogService.selectCentereventTLogById(id));
    }

    /**
     * 新增事件操作日志
     */
    @RequiresPermissions("log:log:add")
    @Log(title = "事件操作日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CentereventTLog centereventTLog)
    {
        return toAjax(centereventTLogService.insertCentereventTLog(centereventTLog));
    }


    /**
     * 新增事件操作日志
     */
    @PostMapping(value = "addappLog")
    public AjaxResult addappLog(@RequestBody CentereventTLog centereventTLog)
    {
        return toAjax(centereventTLogService.insertCentereventTLog(centereventTLog));
    }

    /**
     * 修改事件操作日志
     */
    @RequiresPermissions("log:log:edit")
    @Log(title = "事件操作日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTLog centereventTLog)
    {
        return toAjax(centereventTLogService.updateCentereventTLog(centereventTLog));
    }

    /**
     * 删除事件操作日志
     */
    @RequiresPermissions("log:log:remove")
    @Log(title = "事件操作日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(centereventTLogService.deleteCentereventTLogByIds(ids));
    }
}
