package com.sooka.sponest.event.centereventtreportmessage.controller;

import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.sooka.sponest.event.centereventtreportmessage.domain.CentereventTReportmessage;
import com.sooka.sponest.event.centereventtreportmessage.service.ICentereventTReportmessageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 报文日志Controller
 *
 * @author ruoyi
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/reportmessage")
public class CentereventTReportmessageController extends BaseController {

    @Autowired
    private ICentereventTReportmessageService centereventTReportmessageService;

    /**
     * 查询报文日志列表
     */
    @RequiresPermissions("system:reportmessage:list")
    @GetMapping("/list")
    public TableDataInfo list(CentereventTReportmessage centereventTReportmessage) {
        startPage();
        List<CentereventTReportmessage> list = centereventTReportmessageService.selectCentereventTReportmessageList(centereventTReportmessage);
        return getDataTable(list);
    }

    /**
     * 导出报文日志列表
     */
    @RequiresPermissions("system:reportmessage:export")
    @Log(title = "报文日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CentereventTReportmessage centereventTReportmessage) {
        List<CentereventTReportmessage> list = centereventTReportmessageService.selectCentereventTReportmessageList(centereventTReportmessage);
        ExcelUtil<CentereventTReportmessage> util = new ExcelUtil<>(CentereventTReportmessage.class);
        util.exportExcel(response, list, "报文日志数据");
    }

    /**
     * 获取报文日志详细信息
     */
    @RequiresPermissions("system:reportmessage:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(centereventTReportmessageService.selectCentereventTReportmessageById(id));
    }

    /**
     * 新增报文日志
     */
    @RequiresPermissions("system:reportmessage:add")
    @Log(title = "报文日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CentereventTReportmessage centereventTReportmessage) {
        return toAjax(centereventTReportmessageService.insertCentereventTReportmessage(centereventTReportmessage));
    }

    /**
     * 修改报文日志
     */
    @RequiresPermissions("system:reportmessage:edit")
    @Log(title = "报文日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CentereventTReportmessage centereventTReportmessage) {
        return toAjax(centereventTReportmessageService.updateCentereventTReportmessage(centereventTReportmessage));
    }

    /**
     * 删除报文日志
     */
    @RequiresPermissions("system:reportmessage:remove")
    @Log(title = "报文日志", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(centereventTReportmessageService.deleteCentereventTReportmessageByIds(ids));
    }
}
