package com.sooka.sponest.event.urge;

import com.sooka.sponest.event.urge.domain.EventPush;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.websocket.*;
import javax.websocket.server.PathParam;
import javax.websocket.server.ServerEndpoint;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.concurrent.atomic.AtomicInteger;

@ServerEndpoint("/eventPush/{uid}/{eventTypeDl}/{eventType}")
@Component
public class EventWebSocketServer {

    protected Logger logger = LoggerFactory.getLogger(this.getClass());

    // 静态变量，用来记录当前在线连接数。应该把它设计成线程安全的。
    static final AtomicInteger onlineNum = new AtomicInteger();

    // concurrent包的线程安全Set，用来存放每个客户端对应的WebSocketServer对象。
    static final ConcurrentMap<String, Session> sessionPools = new ConcurrentHashMap<>();

    //建立连接成功调用
    @OnOpen
    public void onOpen(Session session, @PathParam(value = "uid") String uid,
                       @PathParam(value = "eventTypeDl") String eventTypeDl, @PathParam(value = "eventType") String eventType) {
        EventPush eventPush = new EventPush(uid, eventTypeDl, eventType);
        sessionPools.put(eventPush.toString(), session);
        addOnlineCount();
        logger.info("{}加入webSocket！当前人数为{}", uid, onlineNum);
    }

    //关闭连接时调用
    @OnClose
    public void onClose(@PathParam(value = "uid") String uid,
                        @PathParam(value = "eventTypeDl") String eventTypeDl, @PathParam(value = "eventType") String eventType) {
        EventPush eventPush = new EventPush(uid, eventTypeDl, eventType);
        sessionPools.remove(eventPush.toString());
        subOnlineCount();
        logger.info("{}断开webSocket连接！当前人数为{}", uid, onlineNum);
    }

    /**
     * 监听消息事件
     * 可根据自身业务编写逻辑代码
     * 当前代码用于测试redis订阅代码
     *
     * @param message
     */
    @OnMessage
    public void onMessage(String message) {
        logger.info("心跳监测信息：-> {}", message);
    }

    // 错误时调用
    @OnError
    public void onError(Session session, Throwable throwable) {
        logger.error(throwable.getMessage());
    }

    public static void addOnlineCount() {
        onlineNum.incrementAndGet();
    }

    public static void subOnlineCount() {
        onlineNum.decrementAndGet();
    }
}
