package com.sooka.sponest.event.urge.service.impl;

import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.redis.service.RedisService;
import com.sooka.sponest.event.centereventteventcatalogue.domain.CentereventTEventcatalogue;
import com.sooka.sponest.event.centereventteventcatalogue.service.ICentereventTEventcatalogueService;
import com.sooka.sponest.event.centereventteventtype.service.ICentereventTEventtypeService;
import com.sooka.sponest.event.urge.domain.EventReminder;
import com.sooka.sponest.event.urge.service.EventUrgeService;
import com.sooka.sponest.event.utils.EventConstants;
import com.sooka.sponest.event.utils.EventProducerUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Observable;
import java.util.concurrent.TimeUnit;

import static com.sooka.sponest.event.utils.EventConstants.FOREST_EVENT_STATUS_1;

@Service
@EnableAsync
public class EventUrgeServiceImpl implements EventUrgeService, ApplicationRunner {

    private final Logger logger = LoggerFactory.getLogger(EventUrgeServiceImpl.class);

    @Resource
    private ICentereventTEventcatalogueService centereventTEventcatalogueService;

    @Resource
    private ICentereventTEventtypeService centereventTEventtypeService;

    /**
     * 项目启动后运行一次
     *
     * @param args
     */
    @Override
    public void run(ApplicationArguments args) {
        // 找到所有未催办事件
        List<EventReminder> eventUrges = centereventTEventcatalogueService.getReminderTime("sys_isurge_2", FOREST_EVENT_STATUS_1);
        if (StringUtils.isNotEmpty(eventUrges)) {
            long currTime = new Date().getTime();
            RedisService redisServer = SpringUtils.getBean(RedisService.class);
            Collection<String> keys = redisServer.keys(EventConstants.EVENT_URGE_PREFIX + "*");
            eventUrges.forEach(c -> {
                // 设定的超时毫秒数
                long reminderTime = c.getXlReminderTime() != null ? c.getXlReminderTime() : c.getReminderTime();
                // 数据创建时间的毫秒数
                long createTime = c.getCreateTime().getTime();
                if (currTime >= createTime + reminderTime) {
                    EventProducerUtil.urgePublish(c.getEventCode(), 0L);
                } else {
                    if (!keys.contains(EventConstants.EVENT_URGE_PREFIX + c.getEventCode())) {
                        EventProducerUtil.urgePublish(c.getEventCode(), createTime + reminderTime - currTime);
                        redisServer.setCacheObject(EventConstants.EVENT_URGE_PREFIX + c.getEventCode(), c, createTime + reminderTime - currTime, TimeUnit.MILLISECONDS);
                    }
                }
            });
        }
    }

    @Override
    public void update(Observable o, Object arg) {
        logger.info("=======来了一个事件，准备催办=======");
    }

    @Override
    public void toBeUrge(CentereventTEventcatalogue centereventTEventcatalogue) {
        // 误报、重复时无需处理
        if ("forest_event_status_3".equals(centereventTEventcatalogue.getEventStatusValue()) || "forest_event_status_4".equals(centereventTEventcatalogue.getEventStatusValue())) {
            return;
        }
        // 上报时，放入催办任务
        if (FOREST_EVENT_STATUS_1.equals(centereventTEventcatalogue.getEventStatusValue())) {
            long currTime = new Date().getTime();
            long reminderTime = centereventTEventtypeService.getReminderTimeById(centereventTEventcatalogue);
            long createTime = centereventTEventcatalogue.getCreateTime().getTime();
            EventProducerUtil.urgePublish(centereventTEventcatalogue.getEventCode(), createTime + reminderTime - currTime);
            SpringUtils.getBean(RedisService.class).setCacheObject(EventConstants.EVENT_URGE_PREFIX + centereventTEventcatalogue.getEventCode(), centereventTEventcatalogue, createTime + reminderTime - currTime, TimeUnit.MILLISECONDS);
        }
        // 上报、确认、签收时，推送至可视化
        if (FOREST_EVENT_STATUS_1.equals(centereventTEventcatalogue.getEventStatusValue()) || "forest_event_status_7".equals(centereventTEventcatalogue.getEventStatusValue())
                || "forest_event_status_2".equals(centereventTEventcatalogue.getEventStatusValue()) || "forest_event_status_5".equals(centereventTEventcatalogue.getEventStatusValue())) {
            SpringUtils.getBean(RedisService.class).convertAndSend(EventConstants.SOCKET_PUSH_TOPIC, centereventTEventcatalogue);
        }
    }
}
