package com.sooka.sponest.event.utils;

import com.ruoyi.common.log.enums.BusinessType;
import com.sooka.sponest.event.centereventteventcatalogue.domain.bo.EventBO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.stream.function.StreamBridge;
import org.springframework.integration.support.MessageBuilder;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;

@Component
public class EventProducerUtil {

    private static final Logger logger = LoggerFactory.getLogger(EventProducerUtil.class);

    @Autowired
    private StreamBridge streamBridge;

    private static EventProducerUtil instance;

    @PostConstruct
    public void init() {
        instance = this;
        instance.streamBridge = this.streamBridge;
    }

    public static synchronized void publish(String eventCode, BusinessType businessType) {
        EventBO eventBo = new EventBO();
        eventBo.setEventCode(eventCode);
        eventBo.setBusinessType(businessType);
        logger.info("发送消息：{}", eventBo);
        try {
            // MessageBuilder是spring的integration.support.MessageBuilder
            instance.streamBridge.send("mychannel-out-0", MessageBuilder.withPayload(eventBo).setHeader("x-delay", 3000).build());
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
    }

    public static synchronized void urgePublish(String eventCode, Long reminderTime) {
        logger.info("催办事件：{}，延迟时间: {}", eventCode, reminderTime);
        try {
            String channel = "urgechannel-out-0";
            if (0L >= reminderTime) {
                instance.streamBridge.send(channel, MessageBuilder.withPayload(eventCode).build());
            } else {
                instance.streamBridge.send(channel, MessageBuilder.withPayload(eventCode).setHeader("x-delay", reminderTime).build());
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
    }
}
