package com.sooka.sponest.event.utils;

import org.springframework.mock.web.MockMultipartFile;
import org.springframework.web.multipart.MultipartFile;

import javax.net.ssl.*;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.X509Certificate;

public class NetworkImageToMultipartFile {

    /**
     * 从网络路径下载图片并转换为 MultipartFile
     * @param imageUrl 图片的网络路径
     * @return MultipartFile 对象
     */
    public static MultipartFile downloadImageToMultipartFile(String imageUrl) {
        try {
            // 禁用 SSL 证书验证（仅适用于开发环境）
            disableSSLVerification();

            // 打开连接
            URL url = new URL(imageUrl);
            HttpURLConnection connection = (HttpURLConnection) url.openConnection();
            connection.setRequestMethod("GET");

            int responseCode = connection.getResponseCode();
            if (responseCode == HttpURLConnection.HTTP_OK) {
                // 获取输入流
                InputStream inputStream = connection.getInputStream();

                // 获取文件名（从 URL 中提取）
                String fileName = imageUrl.substring(imageUrl.lastIndexOf('/') + 1);

                // 创建 MockMultipartFile
                MultipartFile multipartFile = new MockMultipartFile(
                        fileName, // 文件名
                        fileName, // 原始文件名
                        "image/jpeg", // 文件内容类型
                        inputStream // 输入流
                );

                // 关闭输入流
                inputStream.close();

                return multipartFile;
            } else {
                System.out.println("Failed to download image. Server responded with code: " + responseCode);
            }
        } catch (IOException e) {
            e.printStackTrace();
            System.out.println("Error downloading image: " + e.getMessage());
        } catch (NoSuchAlgorithmException | KeyManagementException e) {
            e.printStackTrace();
            System.out.println("Error disabling SSL verification: " + e.getMessage());
        }
        return null;
    }

    /**
     * 禁用 SSL 证书验证（仅适用于开发环境）
     */
    public static void disableSSLVerification() throws NoSuchAlgorithmException, KeyManagementException {
        // 创建一个信任所有证书的 TrustManager
        TrustManager[] trustAllCerts = new TrustManager[]{
                new X509TrustManager() {
                    public X509Certificate[] getAcceptedIssuers() {
                        return null;
                    }

                    public void checkClientTrusted(X509Certificate[] certs, String authType) {
                    }

                    public void checkServerTrusted(X509Certificate[] certs, String authType) {
                    }
                }
        };

        // 安装全局的信任管理器
        SSLContext sc = SSLContext.getInstance("SSL");
        sc.init(null, trustAllCerts, new java.security.SecureRandom());
        HttpsURLConnection.setDefaultSSLSocketFactory(sc.getSocketFactory());

        // 创建一个 HostnameVerifier，跳过主机名验证
        HostnameVerifier allHostsValid = new HostnameVerifier() {
            public boolean verify(String hostname, SSLSession session) {
                return true;
            }
        };

        HttpsURLConnection.setDefaultHostnameVerifier(allHostsValid);
    }

    public static void main(String[] args) {
        String imageUrl = "https://47.93.50.30:443/media/dji-photos/wayline/1742354657053.JPG";

        // 下载图片并转换为 MultipartFile
        MultipartFile multipartFile = downloadImageToMultipartFile(imageUrl);

        if (multipartFile != null) {
            System.out.println("File Name: " + multipartFile.getOriginalFilename());
            System.out.println("File Size: " + multipartFile.getSize() + " bytes");
        } else {
            System.out.println("Failed to convert image to MultipartFile.");
        }
    }
}
